import request from '@/utils/request'



// 批量通过内容
export function handleUpDateOKShops(shopsId,data) {
  return request({
    url: '/goods/goods/okshops/' + shopsId,
    method: 'post',
    data: data
  })
}


// 查询商品信息列表
export function listGoods(query) {
  return request({
    url: '/goods/goods/list',
    method: 'get',
    params: query
  })
}

// 查询商品信息详细
export function getGoods(goodsId) {
  return request({
    url: '/goods/goods/' + goodsId,
    method: 'get'
  })
}

// 新增商品信息
export function addGoods(data) {
  return request({
    url: '/goods/goods',
    method: 'post',
    data: data
  })
}

// 修改商品信息
export function updateGoods(data) {
  return request({
    url: '/goods/goods',
    method: 'put',
    data: data
  })
}

// 删除商品信息
export function delGoods(goodsId) {
  return request({
    url: '/goods/goods/' + goodsId,
    method: 'delete'
  })
}

// 导出商品信息
export function exportGoods(query) {
  return request({
    url: '/goods/goods/export',
    method: 'get',
    params: query
  })
}
